fcuk-package: fcuk: The Ultimate Helper for Clumsy Fingers

fcuk-packageR Documentation

fcuk: The Ultimate Helper for Clumsy Fingers

Description

Automatically suggests a correction when a typo occurs.

The fcuk package automatically suggests corrections when a typo occurs in R code. It intercepts error messages and provides helpful suggestions based on string distance algorithms.

Main Features

  • Automatic error interception and correction suggestions

  • Support for multiple languages (English, French, German, Spanish, etc.)

  • Quick rerun with '.+1' operator to apply suggested corrections

  • Caching for improved performance

Getting Started

The package is automatically activated when loaded with 'library(fcuk)'. When an error occurs, fcuk will suggest corrections. Use '.+1' to apply the first suggestion, or '.+2' for the second.

Functions

  • [error_analysis()]: Analyse an error and suggest corrections

  • [catch_error()]: Extract object name from error message

  • [error_correction_propostion()]: Find closest matching names

  • [get_all_objects_from_r()]: Get all available object names

  • [init_error_tracker()]: Enable automatic error tracking

  • [remove_error_tracker()]: Disable automatic error tracking

  • [add_fcuk_to_rprofile()]: Add fcuk to your .Rprofile

Author(s)

Maintainer: Vincent Guyader vincent@thinkr.fr (ORCID)

Other contributors:

  • ThinkR [copyright holder]

See Also

Useful links:

Useful links:


fcuk documentation built on Feb. 26, 2026, 5:06 p.m.