powered by
Fetch the name of all objects loaded in the environments (functions, values, data...)
get_all_objets_from_r()
a list with the names of all objects contained in the environments
Run the code above in your browser using DataLab