get_all_objects_from_r: Extract the name of all objects loaded in the R environments
Description
Fetch the name of all objects loaded in the environments (functions, values, data...)
Usage
get_all_objects_from_r(use_cache = TRUE)get_all_objets_from_r(use_cache = TRUE)
Value
A character vector with the names of all objects contained in the environments
Arguments
- use_cache
Logical. Use cached results if available (default: TRUE).
Cache is invalidated when environment changes.